# This Python file uses the following encoding: utf-8

goodbyes=[
    u'totsiens (afrikaans)',
    u'lamtumir\U00000353 (albanian)',
    u'sa\U00000437 olun (azerbaijani)',
    u'agur (basque)',
    u'zbogom (bosnian)',
    u'ad\U00000351u (catalan)',
    u'panamilit (cebuano)',
    u'\U00050615\U00104701 (chinese simplified)',
    u'sbohem (czech)',
    u'farvel (danish)',
    u'afscheid (dutch)',
    u'goodbye (american english)',
    u'pip pip cheerio! (british english)',
    u'adia\U00000355 (esperanto)',
    u'h\U00000374vasti (estonian)',
    u'paalam na (filipino)',
    u'n\U00000344kemiin (finnish)',
    u'au revoir (french)',
    u'adeus (galician)',
    u'auf Wiedersehen (german)', 
    u'\U00001661\U00001675\U00001704\U00001657\U00001677 (greek)',
    u'orevwa (haitian creole)',
    u'sai wata rana (hausa)',
    u'\U00002751\U00002734\U00002725\U00002735 (hebrew)',
    u'sib ntsib dua (hmong)',
    u'b\U00000372cs\U00000372 (hungarian)',
    u'kve\U00000360ja (icelandic)',
    u'selamat tinggal (indonesian)',
    u'beannacht (irish)', 
    u'addio (italian)',
    u'さようなら (japanese)',
    u'pamit (javanese)',
    u'vale (latin)',
    u'ardievas (latvian)',
    u'sudie (lithuanian)',
    u'addiju (maltese)',
    u'poroporoaki (maori)',
    u'farvel (norwegian)',
    u'żegnaj (polish)',
    u'adeus (portuguese)',
    u'la revedere (romanian)',
    u'zbohom (slovak)',
    u'poslovite (slovenian)',
    u'nabdgelyo (somali)',
    u'adi\U00000363s (spanish)',
    u'kwaheri (swahili)',
    u'g\U00000374le g\U00000374le (turkish)',
    u'hwyl fawr (welsh)',
    u'o dab\U00017315 (yoruba)'
]

colors=[
    '\033[1;30m',
    '\033[1;31m',
    '\033[1;32m',
    '\033[1;33m',
    '\033[1;34m',
    '\033[1;35m',
    '\033[1;36m',
    '\033[1;37m'
]
