from distutils.core import setup
from setuptools import setup

with open('Readme.rst', 'r') as f:
        long_description = f.read()

setup(
    zip_safe=False,
    name='cheerio',
    version=1.4,
    author='Lucy Wyman',
    author_email='wyman.lucy@gmail.com',
    description='A cute script to print goodbyes in various languages and colors',
    long_description=long_description,
    packages=['cheerio'],
    package_data={'cheerio': ['*.rst']},
    include_package_data=True,
    keywords=['goodbye', 'cheerio'],
    url='https://github.com/lucywyman/cheerio',
)
